/**
 * While Tailwind does allow for pulling in the configuration and using the theme breakpoints, they
 * do mention that the result will pull in a lot of their build-time dependencies which can result
 * in bigger client side bundle size.
 *
 * This hook can achieve similar results without needing to pull in the Tailwind config. The downside
 * is that the breakpoints could become un-synced if we change them in the tailwind config.
 */
type BreakpointIndicator = "sm" | "md" | "lg" | "xl" | "2xl";
type Breakpoints = {
    [key in BreakpointIndicator]: number;
};
type BreakpointResponse = {
    [key in BreakpointIndicator]: boolean;
} | null;
export declare function useResponsiveBreakpoints(breakpoints?: Breakpoints): BreakpointResponse;
export {};
//# sourceMappingURL=useResponsiveBreakpoints.d.ts.map