import React, { useMemo } from "react";
import "@local-logic/maps/style.css";
import { useLocalContent } from "~/sdks/LocalContent/context";
import { LocalLogicMap } from "@local-logic/maps";
import * as styles from "./styles";
export function Map() {
    const { location, mapProvider } = useLocalContent();
    const mapProviderConfig = useMemo(() => {
        if (typeof mapProvider !== "undefined") {
            if (mapProvider.name !== "maptiler" &&
                typeof mapProvider.key === "undefined") {
                throw new Error(`Map provider key is required. Please provide a valid key for the ${mapProvider.name} map provider.`);
            }
            if (mapProvider.name === "maptiler" &&
                typeof mapProvider.theme === "string" &&
                typeof mapProvider.key === "undefined") {
                // eslint-disable-next-line no-console
                console.warn("MapTiler theme is set but no API key is provided. Please provide a valid MapTiler API key. Using default LocalLogic MapTiler configuration and theme.");
            }
        }
        return {
            name: (mapProvider === null || mapProvider === void 0 ? void 0 : mapProvider.name) || "maptiler",
            apiKey: (mapProvider === null || mapProvider === void 0 ? void 0 : mapProvider.key) || import.meta.env.VITE_MAPTILER_KEY,
            theme: (mapProvider === null || mapProvider === void 0 ? void 0 : mapProvider.theme) || "600d69cb-288d-445e-9839-3dfe4d76b31a",
        };
    }, [mapProvider]);
    // If location is not set or invalid, return a message
    // lat and lng values of 0 are considered invalid for this context
    if (!location || !location.lat || !location.lng) {
        return React.createElement("div", { className: styles.container }, "Location not set");
    }
    return (React.createElement("div", { className: styles.container },
        React.createElement(LocalLogicMap.Root, { mapProvider: mapProviderConfig, center: { latitude: location.lat, longitude: location.lng }, zoomPosition: "bottom-right" },
            React.createElement(LocalLogicMap.BaseMap, null))));
}
//# sourceMappingURL=index.js.map