import React, { useContext, useMemo } from "react";
import { useTracking } from "@local-logic/core/tracking";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
const LocalContentContext = React.createContext({});
const useLocalContent = () => useContext(LocalContentContext);
const LocalContentProvider = ({ children, }) => {
    const { sdkState } = useStateManagerContext();
    const tracking = useTracking();
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const isLoading = useMemo(() => false, []);
    const contextValue = useMemo(() => {
        var _a, _b, _c;
        return ({
            isLoading,
            location: {
                lat: ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.lat) || 0,
                lng: ((_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lng) || 0,
            },
            mapProvider: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.mapProvider,
        });
    }, [isLoading]);
    return (React.createElement(LocalContentContext.Provider, { value: contextValue }, children));
};
export { useLocalContent, LocalContentProvider };
//# sourceMappingURL=context.js.map